WmeClient

Struct WmeClient 

pub struct WmeClient { /* private fields */ }
Main Wikimedia Enterprise API client.

Implementations

Source

impl WmeClient

pub async fn new(config: ClientConfig) -> Result<Self>

Create a new client with the given configuration.

pub fn builder() -> WmeClientBuilder

Create a client builder.

pub fn metadata(&self) -> MetadataClient<'_>

Get the metadata client.

pub fn snapshot(&self) -> SnapshotClient<'_>

Get the snapshot client.

pub fn on_demand(&self) -> OnDemandClient<'_>

Get the on-demand client.

pub fn realtime(&self) -> RealtimeClient<'_>

Get the realtime client.

pub fn token_manager(&self) -> Option<&TokenManager>

Get the token manager if available.

Returns Some(&TokenManager) if the client was built with credentials, or None if the client was built without authentication.

This allows CLI applications to retrieve tokens after login for storage, or to set tokens from a previous session.